﻿using ProjectTrolleybus.Entities;

namespace ProjectTrolleybus.Drawnings;

/// <summary>
/// Класс, отвечающий за прорисовку и перемещение объекта-сущности
/// </summary>
public class DrawningTrolleybus : DrawningTrolleyB
{
    /// <summary>
    /// Конструктор
    /// </summary>
    /// <param name="speed"></param>
    /// <param name="weight"></param>
    /// <param name="bodyColor"></param>
    /// <param name="additionalColor"></param>
    /// <param name="batteryCompartment"></param>
    /// <param name="horns"></param>
    /// 
    public DrawningTrolleybus(int speed, double weight, Color bodyColor, Color additionalColor, bool batteryCompartment, bool horns) : base(100, 48)
    {
        EntityTrolleyB = new EntityTrolleybus(speed, weight, bodyColor, additionalColor, batteryCompartment, horns);
    }

    /// <summary>
    /// Конструктор, принимающий объект EntityTrolleyB в качестве параметра
    /// </summary>
    /// <param name="entityTrolleyB"></param>
    public DrawningTrolleybus(EntityTrolleybus exc) : base(120, 80)
    {
        EntityTrolleyB = new EntityTrolleybus(exc.Speed, exc.Weight, exc.BodyColor, exc.AdditionalColor, exc.BatteryCompartment, exc.Horns);
    }

    public override void DrawTransport(Graphics g)
    {

        if (EntityTrolleyB == null || EntityTrolleyB is not EntityTrolleybus trolleybus || !_startPosX.HasValue || !_startPosY.HasValue)
        {
            return;
        }

        Pen pen = new(Color.Black);
        Brush additBrush = new SolidBrush(trolleybus.AdditionalColor);

        // "Рога" для проводов
        if (trolleybus.Horns)
        {
            pen.Width = 2;
            g.DrawLine(pen, _startPosX.Value + 77, _startPosY.Value + 15, _startPosX.Value + 52, _startPosY.Value + 2);
            pen.Width = 1;
            g.DrawRectangle(pen, _startPosX.Value + 34, _startPosY.Value, 20, 5);

            g.FillRectangle(additBrush, _startPosX.Value + 35, _startPosY.Value + 1, 19, 4);

        }

        // Отсек под батареи
        if (trolleybus  .BatteryCompartment)
        {
            g.DrawRectangle(pen, _startPosX.Value, _startPosY.Value + 24, 10, 12);

            g.FillRectangle(additBrush, _startPosX.Value + 1, _startPosY.Value + 25, 9, 11);
        }

        _startPosX += 10;
        _startPosY += 15;
        base.DrawTransport(g);
        _startPosX -= 10;
        _startPosY -= 15;
    }

}
