﻿namespace ProjectTrolleybus.Entities;
/// <summary>
/// Класс-Сущность "Троллейбус"
/// </summary>
public class EntityTrolleybus : EntityTrolleyB
{
    /// <summary>
    /// Дополнительный цвет
    /// </summary>
    public Color AdditionalColor { get; private set; }

    public void setAdditionalColor(Color color)
    {
        AdditionalColor = color;
    }

    /// <summary>
    /// Признак (опция) наличия отсека под батареи
    /// </summary>
    public bool BatteryCompartment { get; private set; }

    /// <summary>
    /// Признак (опция) наличия "Рогов" для подключения проводов
    /// </summary>
    public bool Horns { get; private set; }

    /// <summary>
    /// 
    /// </summary>
    /// <param name="speed"></param>
    /// <param name="weight"></param>
    /// <param name="bodyColor"></param>
    /// <param name="additionalColor"></param>
    /// <param name="batteryCompartment"></param>
    /// <param name="horns"></param>
    public EntityTrolleybus(int speed, double weight, Color bodyColor, Color additionalColor, bool batteryCompartment, bool horns) : base(speed, weight, bodyColor)
    {
        AdditionalColor = additionalColor;
        BatteryCompartment = batteryCompartment;
        Horns = horns;
    }

    /// <summary>
    /// Получение строк со значениями свойств объекта класса-сущности
    /// </summary>
    /// <returns></returns>
    public override string[] GetStringRepresentation()
    {
        return new[] { nameof(EntityTrolleybus), Speed.ToString(), Weight.ToString(), BodyColor.Name, AdditionalColor.Name, BatteryCompartment.ToString(), Horns.ToString() };
    }

    /// <summary>
    /// Создание объекта из массива строк
    /// </summary>
    /// <param name="strs"></param>
    /// <returns></returns>
    public static EntityTrolleybus? CreateEntityTrolleybus(string[] strs)
    {
        if (strs.Length != 7 || strs[0] != nameof(EntityTrolleybus))
        {
            return null;
        }

        return new EntityTrolleybus(Convert.ToInt32(strs[1]), Convert.ToDouble(strs[2]), Color.FromName(strs[3]), Color.FromName(strs[4]), Convert.ToBoolean(strs[5]), Convert.ToBoolean(strs[6]));
    }
}
