﻿using ProjectTrolleybus.Drawnings;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ProjectTrolleybus.MovementStrategy;

/// <summary>
/// Класс-реализация IMoveableObject с использованием DrawningTrolleyB
/// </summary>
public class MoveableTrolleyB : IMoveableObject
{
    /// <summary>
    /// Поле-объект класса DrawningTrolleyB или его наследника
    /// </summary>
    private readonly DrawningTrolleyB? _trolleyB = null;
    
    /// <summary>
    /// Конструктор
    /// </summary>
    /// <param name="trolleyB">Объект класса DrawningTrolleyB</param>
    public MoveableTrolleyB(DrawningTrolleyB trolleyB)
    {
        _trolleyB = trolleyB;
    }

    public ObjectParameters? GetObjectPosition
    {
        get
        {
            if (_trolleyB == null || _trolleyB.EntityTrolleyB == null || !_trolleyB.GetPosX.HasValue || !_trolleyB.GetPosY.HasValue)
            {
                return null;
            }
            return new ObjectParameters(_trolleyB.GetPosX.Value, _trolleyB.GetPosY.Value, _trolleyB.GetWidth, _trolleyB.GetHight);
        }
    }

    public int GetStep => (int)(_trolleyB?.EntityTrolleyB?.Step ?? 0);

    public bool TryMoveObject(MovementDirection direction)
    {
        if (_trolleyB == null || _trolleyB.EntityTrolleyB == null)
        {
            return false;
        }

        return _trolleyB.MoveVehicle(GetDirectionType(direction));
    }

    /// <summary>
    /// Конвертация из MovementDirection в DirectionType
    /// </summary>
    /// <param name="direction">MovementDirection</param>
    /// <returns>DirectionType</returns>
    private static DirectionType GetDirectionType(MovementDirection direction)
    {
        return direction switch
        {
            MovementDirection.Left => DirectionType.Left,
            MovementDirection.Right => DirectionType.Right,
            MovementDirection.Up => DirectionType.Up,
            MovementDirection.Down => DirectionType.Down,
            _ => DirectionType.Unknow,
        };
    }
}
